@@ -264,13 +264,7 @@ def stress_cpu(filter_vmss: str = None,
         with concurrent.futures.ThreadPoolExecutor(max_workers=len(instances)) as executor:
             for instance in instances:
                 command_id, script_content = command.prepare(instance, operation_name)
-                parameters = {
-                    'command_id': command_id,
-                    'script': [script_content],
-                    'parameters': [
-                        {'name': "input_duration", 'value': duration}
-                    ]
-                }
+                parameters = command.fill_parameters(command_id, script_content, duration=duration)
 
                 # collect future results
                 futures.append(
@@ -310,7 +304,7 @@ def burn_io(filter_vmss: str = None,
         Duration of the stress test (in seconds) that generates high disk I/O operations. Defaults to 60 seconds.
 
     path : str, optional
-        The absolute path to write the stress file into. Defaults to ``C:\burn`` for Windows
+        The absolute path to write the stress file into. Defaults to ``C:\\burn`` for Windows
         clients and ``/root/burn`` for Linux clients.
     """
     operation_name = burn_io.__name__
@@ -331,14 +325,7 @@ def burn_io(filter_vmss: str = None,
             for instance in instances:
                 command_id, script_content = command.prepare(instance, operation_name)
                 fill_path = command.prepare_path(instance, path)
-                parameters = {
-                    'command_id': command_id,
-                    'script': [script_content],
-                    'parameters': [
-                        {'name': "input_duration", 'value': duration},
-                        {'name': "input_path", 'value': fill_path}
-                    ]
-                }
+                parameters = command.fill_parameters(command_id, script_content, duration=duration, path=fill_path)
 
                 # collect future results
                 futures.append(
@@ -383,7 +370,7 @@ def fill_disk(filter_vmss: str = None,
 
     path : str, optional
         Location of the stressing file where it is generated. Defaults to ``/root/burn`` on Linux systems
-        and ``C:/burn`` on Windows machines.
+        and ``C:\\burn`` on Windows machines.
     """
     operation_name = fill_disk.__name__
 
@@ -406,16 +393,8 @@ def fill_disk(filter_vmss: str = None,
             for instance in instances:
                 command_id, script_content = command.prepare(instance, operation_name)
                 fill_path = command.prepare_path(instance, path)
-
-                parameters = {
-                    'command_id': command_id,
-                    'script': [script_content],
-                    'parameters': [
-                        {'name': "input_duration", 'value': duration},
-                        {'name': "input_size", 'value': size},
-                        {'name': "input_path", 'value': fill_path}
-                    ]
-                }
+                parameters = command.fill_parameters(
+                    command_id, script_content, duration=duration, size=size, path=fill_path)
 
                 # collect the future results
                 futures.append(
@@ -486,16 +465,9 @@ def network_latency(filter_vmss: str = None,
         with concurrent.futures.ThreadPoolExecutor(max_workers=len(instances)) as executor:
             for instance in instances:
                 command_id, script_content = command.prepare(instance, operation_name)
-                parameters = {
-                    'command_id': command_id,
-                    'script': [script_content],
-                    'parameters': [
-                        {'name': "input_duration", 'value': duration},
-                        {'name': "input_delay", 'value': delay},
-                        {'name': "input_jitter", 'value': jitter},
-                        {'name': "input_network_interface", 'value': network_interface}
-                    ]
-                }
+                parameters = command.fill_parameters(
+                    command_id, script_content, duration=duration, delay=delay, jitter=jitter,
+                    network_interface=network_interface)
 
                 # collect the future results
                 futures.append(
